@@ -1,7 +1,12 @@
 """Setup for the chocobo package."""
 
 import setuptools
+import os
 
+if os.environ.get('CI_COMMIT_TAG'):
+    version = os.environ['CI_COMMIT_TAG']
+else:
+    version = os.environ['CI_JOB_ID']
 
 with open('README.md') as f:
     README = f.read()
@@ -11,9 +16,9 @@ setuptools.setup(
     author_email="abhay@trell.in",
     name='trell_ai_utils',
     description='Utility code for trell ai repos',
-    version='v0.1.25',
+    version=version,
     long_description=README,
-    url='https://gitlab.com/abhay7/trell-ai-util',
+    url='https://gitlab.com/trell/trell-ai-util',
     packages=setuptools.find_packages(),
     python_requires=">=3.6.9",
     install_requires=['requests','emoji','json-utils', 'python-dotenv', 'pandas_gbq',
